==> adams-meta-0.4.0-sources.jar: adams/flow/core/AbstractCopyGlobalActor.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * AbstractCopyGlobalActor.java
 * Copyright (C) 2012 University of Waikato, Hamilton, New Zealand
 */
package adams.flow.core;

import java.util.HashSet;

import adams.core.Variables;

/**
 * Ancestor for actors that use a copy of a global actor.
 * 
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 5789 $
 */
public abstract class AbstractCopyGlobalActor
  extends AbstractActor 
  implements GlobalActorHandler {

  /** for serialization. */
  private static final long serialVersionUID = -7860206690560690212L;

  /** the global name. */
  protected GlobalActorReference m_GlobalName;

  /** the global actor. */
  protected AbstractActor m_GlobalActor;

  /** the helper class. */
  protected GlobalActorHelper m_Helper;

  /**
   * Adds options to the internal list of options.
   */
  @Override
  public void defineOptions() {
    super.defineOptions();

    m_OptionManager.add(
	    "global", "globalName",
	    new GlobalActorReference("unknown"));
  }

  /**
   * Initializes the members.
   */
  @Override
  protected void initialize() {
    super.initialize();

    m_Helper = new GlobalActorHelper();
  }

  /**
   * Sets the name of the global actor to use.
   *
   * @param value 	the global name
   */
  public void setGlobalName(GlobalActorReference value) {
    m_GlobalName = value;
    reset();
  }

  /**
   * Returns the name of the global actor in use.
   *
   * @return 		the global name
   */
  public GlobalActorReference getGlobalName() {
    return m_GlobalName;
  }

  /**
   * Returns the tip text for this property.
   *
   * @return 		tip text for this property suitable for
   * 			displaying in the GUI or for listing the options.
   */
  public String globalNameTipText() {
    return "The name of the global actor to use.";
  }

  /**
   * Returns a quick info about the actor, which will be displayed in the GUI.
   *
   * @return		null if no info available, otherwise short string
   */
  @Override
  public String getQuickInfo() {
    String	variable;

    variable = getOptionManager().getVariableForProperty("globalName");

    if (variable != null)
      return variable;
    else if ((m_GlobalName != null) && (m_GlobalName.toString().length() > 0))
      return m_GlobalName.toString();
    else
      return null;
  }

  /**
   * Tries to find the global actor referenced by its global name.
   *
   * @return		the global actor or null if not found
   */
  protected AbstractActor findGlobalActor() {
    return m_Helper.findGlobalActorRecursive(this, getGlobalName());
  }

  /**
   * Checks whether a reference to the global actor is currently available.
   *
   * @return		true if a reference is available
   * @see		#getGlobalActor()
   */
  public boolean hasGlobalActor() {
    return (m_GlobalActor != null);
  }

  /**
   * Returns the currently set global actor.
   *
   * @return		the actor, can be null
   */
  @Override
  public AbstractActor getGlobalActor() {
    return m_GlobalActor;
  }
  
  /**
   * Updates the Variables instance in use.
   * <p/>
   * Use with caution!
   *
   * @param value	the instance to use
   */
  @Override
  protected void forceVariables(Variables value) {
    super.forceVariables(value);

    if (m_GlobalActor != null)
      m_GlobalActor.setVariables(value);
  }

  /**
   * Initializes the item for flow execution.
   *
   * @return		null if everything is fine, otherwise error message
   */
  @Override
  public String setUp() {
    String		result;
    HashSet<String>	variables;

    result = super.setUp();

    if (result == null) {
      m_GlobalActor = findGlobalActor();
      if (m_GlobalActor == null) {
        result = "Couldn't find global actor '" + getGlobalName() + "'!";
      }
      else {
	m_GlobalActor = m_GlobalActor.shallowCopy();
	m_GlobalActor.setParent(getParent());
	m_GlobalActor.setVariables(getVariables());
	result        = m_GlobalActor.setUp();
	if (result == null) {
	  variables = findVariables(m_GlobalActor);
	  m_DetectedVariables.addAll(variables);
	  if (m_DetectedVariables.size() > 0)
	    getVariables().addVariableChangeListener(this);
	}
      }
    }

    return result;
  }

  /**
   * Executes the global actor. Derived classes might need to override this
   * method to ensure atomicity.
   *
   * @return		null if no error, otherwise error message
   */
  protected abstract String executeGlobalActor();

  /**
   * Executes the flow item.
   *
   * @return		null if everything is fine, otherwise error message
   */
  @Override
  protected String doExecute() {
    String	result;

    result = null;

    if (!m_GlobalActor.getSkip() && !m_GlobalActor.isStopped())
      result = executeGlobalActor();

    return result;
  }

  /**
   * Returns whether the actor has finished.
   *
   * @return		true if finished
   */
  @Override
  public boolean isFinished() {
    if (m_GlobalActor == null)
      return true;
    else
      return m_GlobalActor.isFinished();
  }

  /**
   * Stops the execution. No message set.
   */
  @Override
  public void stopExecution() {
    if (m_GlobalActor != null)
      m_GlobalActor.stopExecution();

    super.stopExecution();
  }

  /**
   * Cleans up after the execution has finished. Graphical output is left
   * untouched.
   */
  @Override
  public void wrapUp() {
    if (m_GlobalActor != null)
      m_GlobalActor.wrapUp();

    super.wrapUp();
  }

  /**
   * Cleans up after the execution has finished.
   */
  @Override
  public void cleanUp() {
    super.cleanUp();

    if (m_GlobalActor != null) {
      m_GlobalActor.cleanUp();
      m_GlobalActor = null;
    }
  }
}

==> adams-meta-0.4.2-sources.jar: adams/flow/core/AbstractCopyGlobalActor.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * AbstractCopyGlobalActor.java
 * Copyright (C) 2012 University of Waikato, Hamilton, New Zealand
 */
package adams.flow.core;

import java.util.HashSet;

import adams.core.Variables;

/**
 * Ancestor for actors that use a copy of a global actor.
 * 
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 5950 $
 */
public abstract class AbstractCopyGlobalActor
  extends AbstractActor 
  implements GlobalActorUser {

  /** for serialization. */
  private static final long serialVersionUID = -7860206690560690212L;

  /** the global name. */
  protected GlobalActorReference m_GlobalName;

  /** the global actor. */
  protected AbstractActor m_GlobalActor;

  /** the helper class. */
  protected GlobalActorHelper m_Helper;

  /**
   * Adds options to the internal list of options.
   */
  @Override
  public void defineOptions() {
    super.defineOptions();

    m_OptionManager.add(
	    "global", "globalName",
	    new GlobalActorReference("unknown"));
  }

  /**
   * Initializes the members.
   */
  @Override
  protected void initialize() {
    super.initialize();

    m_Helper = new GlobalActorHelper();
  }

  /**
   * Sets the name of the global actor to use.
   *
   * @param value 	the global name
   */
  public void setGlobalName(GlobalActorReference value) {
    m_GlobalName = value;
    reset();
  }

  /**
   * Returns the name of the global actor in use.
   *
   * @return 		the global name
   */
  public GlobalActorReference getGlobalName() {
    return m_GlobalName;
  }

  /**
   * Returns the tip text for this property.
   *
   * @return 		tip text for this property suitable for
   * 			displaying in the GUI or for listing the options.
   */
  public String globalNameTipText() {
    return "The name of the global actor to use.";
  }

  /**
   * Returns a quick info about the actor, which will be displayed in the GUI.
   *
   * @return		null if no info available, otherwise short string
   */
  @Override
  public String getQuickInfo() {
    String	variable;

    variable = getOptionManager().getVariableForProperty("globalName");

    if (variable != null)
      return variable;
    else if ((m_GlobalName != null) && (m_GlobalName.toString().length() > 0))
      return m_GlobalName.toString();
    else
      return null;
  }

  /**
   * Tries to find the global actor referenced by its global name.
   *
   * @return		the global actor or null if not found
   */
  protected AbstractActor findGlobalActor() {
    return m_Helper.findGlobalActorRecursive(this, getGlobalName());
  }

  /**
   * Checks whether a reference to the global actor is currently available.
   *
   * @return		true if a reference is available
   * @see		#getGlobalActor()
   */
  public boolean hasGlobalActor() {
    return (m_GlobalActor != null);
  }

  /**
   * Returns the currently set global actor.
   *
   * @return		the actor, can be null
   */
  @Override
  public AbstractActor getGlobalActor() {
    return m_GlobalActor;
  }
  
  /**
   * Updates the Variables instance in use.
   * <p/>
   * Use with caution!
   *
   * @param value	the instance to use
   */
  @Override
  protected void forceVariables(Variables value) {
    super.forceVariables(value);

    if (m_GlobalActor != null)
      m_GlobalActor.setVariables(value);
  }

  /**
   * Initializes the item for flow execution.
   *
   * @return		null if everything is fine, otherwise error message
   */
  @Override
  public String setUp() {
    String		result;
    HashSet<String>	variables;

    result = super.setUp();

    if (result == null) {
      m_GlobalActor = findGlobalActor();
      if (m_GlobalActor == null) {
        result = "Couldn't find global actor '" + getGlobalName() + "'!";
      }
      else {
	m_GlobalActor = m_GlobalActor.shallowCopy();
	m_GlobalActor.setParent(getParent());
	m_GlobalActor.setVariables(getVariables());
	result        = m_GlobalActor.setUp();
	if (result == null) {
	  variables = findVariables(m_GlobalActor);
	  m_DetectedVariables.addAll(variables);
	  if (m_DetectedVariables.size() > 0)
	    getVariables().addVariableChangeListener(this);
	}
      }
    }

    return result;
  }

  /**
   * Executes the global actor. Derived classes might need to override this
   * method to ensure atomicity.
   *
   * @return		null if no error, otherwise error message
   */
  protected abstract String executeGlobalActor();

  /**
   * Executes the flow item.
   *
   * @return		null if everything is fine, otherwise error message
   */
  @Override
  protected String doExecute() {
    String	result;

    result = null;

    if (!m_GlobalActor.getSkip() && !m_GlobalActor.isStopped())
      result = executeGlobalActor();

    return result;
  }

  /**
   * Returns whether the actor has finished.
   *
   * @return		true if finished
   */
  @Override
  public boolean isFinished() {
    if (m_GlobalActor == null)
      return true;
    else
      return m_GlobalActor.isFinished();
  }

  /**
   * Stops the execution. No message set.
   */
  @Override
  public void stopExecution() {
    if (m_GlobalActor != null)
      m_GlobalActor.stopExecution();

    super.stopExecution();
  }

  /**
   * Cleans up after the execution has finished. Graphical output is left
   * untouched.
   */
  @Override
  public void wrapUp() {
    if (m_GlobalActor != null)
      m_GlobalActor.wrapUp();

    super.wrapUp();
  }

  /**
   * Cleans up after the execution has finished.
   */
  @Override
  public void cleanUp() {
    super.cleanUp();

    if (m_GlobalActor != null) {
      m_GlobalActor.cleanUp();
      m_GlobalActor = null;
    }
  }
}
